<p align="center">
  <a"><img src="docs/logo2.png" width="500" alt="logo"></a>
</p>

<div align="center">

# NoneBot-Adapter-Kaiheila

_✨ 开黑啦协议适配 ✨_

</div>

## 个人工作繁忙时间不多， 欢迎有想法的各位共同维护仓库

## Manual

[使用指南](./MANUAL.md)
